# Changelog

## v0.1.0a4

  * Added Python wheel support
  * Improved server message handling
  * First simulator logic for server
  * Client setter commands

## v0.1.0a3

  * Marked package as PEP561 compatible

## v0.1.0a2

  * Improved documentation
  * Added methods for requesting server status/settings

## v0.1.0a1

  * Created `tololib` project
